@@ -3,7 +3,7 @@ package DhMakePerl::Command::Packaging;
 use strict;
 use warnings;
 
-our $VERSION = '0.114';
+our $VERSION = '0.116';
 
 use feature 'switch';
 
@@ -269,7 +269,7 @@ sub get_wnpp {
     return undef unless $self->cfg->network;
 
     my $wnpp = Debian::WNPP::Query->new(
-        { cache_file => catfile( $self->cfg->home_dir, 'wnpp.cache' ) } );
+        { cache_file => catfile( $self->cfg->cache_dir, 'wnpp.cache' ) } );
     my @bugs = $wnpp->bugs_for_package($package);
     return $bugs[0];
 }
@@ -897,7 +897,7 @@ sub create_rules {
         = ( $arch eq 'all' ? 'rules.dh.tiny.all' : 'rules.dh.tiny.any' );
 
     for my $source (
-        catfile( $self->cfg->home_dir, $rulesname ),
+        catfile( $self->cfg->config_dir, $rulesname ),
         catfile( $self->cfg->data_dir, $rulesname )
     ) {
         if ( -e $source ) {
@@ -1371,7 +1371,7 @@ sub discover_dependencies {
         my $wnpp_query;
         $wnpp_query
             = Debian::WNPP::Query->new(
-            { cache_file => catfile( $self->cfg->home_dir, 'wnpp.cache' ) } )
+            { cache_file => catfile( $self->cfg->cache_dir, 'wnpp.cache' ) } )
             if $self->cfg->network;
 
         # control->discover_dependencies needs configured CPAN
