@@ -3,7 +3,7 @@ package DhMakePerl::Config;
 use strict;
 use warnings;
 
-our $VERSION = '0.114';
+our $VERSION = '0.116';
 
 =head1 NAME
 
@@ -20,7 +20,9 @@ my @OPTIONS = (
     'bdepends=s',      'bdependsi=s',
     'build-source!',
     'build!',          'closes=i',
-    'config-file=s',   'core-ok',
+    'cache-dir=s',
+    'config-dir=s',    'config-file=s',
+    'core-ok',
     'cpan-mirror=s',   'cpan=s',
     'cpanplus=s',      'data-dir=s',
     'dbflags=s',       'depends=s',
@@ -64,6 +66,11 @@ use Getopt::Long;
 use Tie::IxHash ();
 use YAML        ();
 
+use constant XDG_HOME => {
+    CONFIG => $ENV{XDG_CONFIG_HOME} || "$ENV{HOME}/.config",
+    CACHE  => $ENV{XDG_CACHE_HOME} || "$ENV{HOME}/.cache",
+};
+
 use constant DEFAULTS => {
     backups       => 1,
     data_dir      => '/usr/share/dh-make-perl',
@@ -73,6 +80,8 @@ use constant DEFAULTS => {
     email         => '',
     exclude       => Dpkg::Source::Package->get_default_diff_ignore_regex(),
     home_dir      => "$ENV{HOME}/.dh-make-perl",
+    config_dir    => XDG_HOME->{CONFIG} . "/dh-make-perl",
+    cache_dir     => XDG_HOME->{CACHE} . "/dh-make-perl",
     network       => 1,
     only          => {
         map (
@@ -158,6 +167,18 @@ sub parse_command_line_options {
         = { map ( ( $_ => 1 ), split( /,/, join( ',', @{ $opts{only} } ) ) ) }
         if $opts{only};
 
+    # Handle backwards compatibility. Explicit --cache-dir or --config-dir
+    # have preference over --home-dir. If none is specified and the legacy
+    # home directory exists use that, otherwise use the XDG directories.
+    my $home_dir = $opts{'home-dir'};
+    if ( -d $self->DEFAULTS->{home_dir} ) {
+        $home_dir //= $self->DEFAULTS->{home_dir};
+    }
+    if ( defined $home_dir ) {
+        $opts{'config-dir'} //= $home_dir;
+        $opts{'cache-dir'} //= $home_dir;
+    }
+
     while ( my ( $k, $v ) = each %opts ) {
         my $field = $k;
         $field =~ s/-/_/g;
@@ -236,7 +257,7 @@ sub parse_command_line_options {
 =item parse_config_file()
 
 Parse configuration file. I<config_file> member is used for location the file,
-if not set, F<dh-make-perl.conf> file in I<home_dir> is used.
+if not set, F<dh-make-perl.conf> file in I<config_dir> is used.
 
 =cut
 
@@ -244,7 +265,7 @@ sub parse_config_file {
     my $self = shift;
 
     my $fn = $self->config_file
-        || catfile( $self->home_dir, 'dh-make-perl.conf' );
+        || catfile( $self->config_dir, 'dh-make-perl.conf' );
 
     if ( -e $fn ) {
         local $@;
